All of lore.kernel.org
 help / color / mirror / Atom feed
From: Sean Christopherson <sean.j.christopherson@intel.com>
To: Jarkko Sakkinen <jarkko.sakkinen@linux.intel.com>
Cc: linux-sgx@vger.kernel.org
Subject: [PATCH for_v23 03/16] x86/vdso: sgx: Rename the enclave exit handler typedef
Date: Mon,  7 Oct 2019 21:46:00 -0700	[thread overview]
Message-ID: <20191008044613.12350-4-sean.j.christopherson@intel.com> (raw)
In-Reply-To: <20191008044613.12350-1-sean.j.christopherson@intel.com>

Rename the exit handler callback to sgx_enclave_exit_handler_t so that
the name itself describes the purpose of the function to some extent.

Signed-off-by: Sean Christopherson <sean.j.christopherson@intel.com>
---
 arch/x86/entry/vdso/vsgx_enter_enclave.S | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/arch/x86/entry/vdso/vsgx_enter_enclave.S b/arch/x86/entry/vdso/vsgx_enter_enclave.S
index 06e18a2836de..5fbe07a03e6c 100644
--- a/arch/x86/entry/vdso/vsgx_enter_enclave.S
+++ b/arch/x86/entry/vdso/vsgx_enter_enclave.S
@@ -53,12 +53,12 @@
  *    -EFAULT if ENCL or the enclave faults or non-positive value is returned
  *     from the callback.
  */
-typedef int (*sgx_callback)(long rdi, long rsi, long rdx, int ret,
-			    long r8, long r9, void *tcs, long ursp,
-			    struct sgx_enclave_exception *e);
+typedef int (*sgx_enclave_exit_handler_t)(long rdi, long rsi, long rdx, int ret,
+					  long r8, long r9, void *tcs, long ursp,
+					  struct sgx_enclave_exception *e);
 int __vdso_sgx_enter_enclave(int leaf, void *tcs,
 			     struct sgx_enclave_exception *e,
-			     sgx_callback callback);
+			     sgx_enclave_exit_handler_t handler);
 #endif
 ENTRY(__vdso_sgx_enter_enclave)
 	/* Prolog */
@@ -86,17 +86,17 @@ ENTRY(__vdso_sgx_enter_enclave)
 	xor	%eax, %eax
 3:	mov	%eax, %ecx
 
 	/* Call *callback if supplied */
 	mov	0x20(%rbp), %rax
 	test	%rax, %rax
 	jz	7f
 	/* Align stack per x86_64 ABI. The original %rsp is saved in %rbx to be
 	 * restored after *callback returns. */
 	mov	%rsp, %rbx
 	and	$-0x10, %rsp
 	/* Clear RFLAGS.DF per x86_64 ABI */
 	cld
-	/* Parameters for *callback */
+	/* Parameters for the exit handler */
 	push	0x18(%rbp)
 	push	%rbx
 	push	0x10(%rbp)
@@ -105,9 +105,9 @@ ENTRY(__vdso_sgx_enter_enclave)
 	/* Restore %rsp to its original value left off by the enclave from last
 	 * exit */
 	mov	%rbx, %rsp
 	/* Positive return value from *callback will be interpreted as an ENCLU
 	 * leaf, while a non-positive value will be interpreted as the return
 	 * value to be passed back to the caller. */
 	jmp	1b
 40:	/* retpoline */
 	call	42f
@@ -86,17 +86,17 @@ ENTRY(__vdso_sgx_enter_enclave)
 3:	mov	%eax, %ecx
 
-	/* Call *callback if supplied */
+	/* Call the exit handler if supplied */
 	mov	0x20(%rbp), %rax
 	test	%rax, %rax
@@ -86,17 +86,17 @@ ENTRY(__vdso_sgx_enter_enclave)
 	jz	7f
 	/* Align stack per x86_64 ABI. The original %rsp is saved in %rbx to be
-	 * restored after *callback returns. */
+	 * restored after the exit handler returns. */
 	mov	%rsp, %rbx
 	and	$-0x10, %rsp
@@ -105,9 +105,9 @@ ENTRY(__vdso_sgx_enter_enclave)
 	 * exit */
 	mov	%rbx, %rsp
-	/* Positive return value from *callback will be interpreted as an ENCLU
-	 * leaf, while a non-positive value will be interpreted as the return
-	 * value to be passed back to the caller. */
+	/* Positive return value from the exit handler will be interpreted as
+	 * an ENCLU leaf, while a non-positive value will be interpreted as the
+	 * return value to be passed back to the caller. */
 	jmp	1b
 40:	/* retpoline */
-- 
2.22.0


  parent reply	other threads:[~2019-10-08  4:46 UTC|newest]

Thread overview: 36+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-10-08  4:45 [PATCH for_v23 00/16] x86/vdso: sgx: Major vDSO cleanup Sean Christopherson
2019-10-08  4:45 ` [PATCH for_v23 01/16] x86/vdso: sgx: Drop the pseudocode "documentation" Sean Christopherson
2019-10-08  4:45 ` [PATCH for_v23 02/16] x86/vdso: sgx: Do not use exception info to pass success/failure Sean Christopherson
2019-10-08  4:46 ` Sean Christopherson [this message]
2019-10-08  4:46 ` [PATCH for_v23 04/16] x86/vdso: sgx: Move enclave exit handler declaration to UAPI header Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 05/16] x86/vdso: sgx: Add comment regarding kernel-doc shenanigans Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 06/16] x86/vdso: sgx: Rewrite __vdso_sgx_enter_enclave() function comment Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 07/16] selftests/x86: Fix linker warning in SGX selftest Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 08/16] selftests/x86/sgx: Use getauxval() to retrieve the vDSO base address Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 09/16] selftests/x86/sgx: Add helper function and macros to assert results Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 10/16] selftests/x86/sgx: Handle setup failures via test assertions Sean Christopherson
2019-10-15 10:16   ` Jarkko Sakkinen
2019-10-15 10:24     ` Jarkko Sakkinen
2019-10-15 10:25       ` Jarkko Sakkinen
2019-10-15 11:03         ` Jarkko Sakkinen
2019-10-15 16:27           ` Sean Christopherson
2019-10-16 10:20             ` Jarkko Sakkinen
2019-10-16 20:21         ` Sean Christopherson
2019-10-15 16:18     ` Sean Christopherson
2019-10-16 10:19       ` Jarkko Sakkinen
2019-10-08  4:46 ` [PATCH for_v23 11/16] selftests/x86/sgx: Sanitize the types for sgx_call()'s input params Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 12/16] selftests/x86/sgx: Move existing sub-test to a separate helper Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 13/16] selftests/x86/sgx: Add a test of the vDSO exception reporting mechanism Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 14/16] selftests/x86/sgx: Add test of vDSO with basic exit handler Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 15/16] selftests/x86/sgx: Add sub-test for exception behavior with " Sean Christopherson
2019-10-08  4:46 ` [PATCH for_v23 16/16] x86/vdso: sgx: Rework __vdso_sgx_enter_enclave() to prefer "no callback" Sean Christopherson
2019-10-09 18:00   ` Xing, Cedric
2019-10-09 19:10     ` Sean Christopherson
2019-10-10  0:21       ` Sean Christopherson
2019-10-10 17:49       ` Xing, Cedric
2019-10-10 23:59         ` Sean Christopherson
2019-10-16 22:18           ` Xing, Cedric
2019-10-16 22:53             ` Sean Christopherson
2019-10-10  8:10 ` [PATCH for_v23 00/16] x86/vdso: sgx: Major vDSO cleanup Jarkko Sakkinen
2019-10-10 16:08   ` Sean Christopherson
2019-10-14 21:04     ` Jarkko Sakkinen

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20191008044613.12350-4-sean.j.christopherson@intel.com \
    --to=sean.j.christopherson@intel.com \
    --cc=jarkko.sakkinen@linux.intel.com \
    --cc=linux-sgx@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.